admin_bootstrap

Function admin_bootstrap 

pub async fn admin_bootstrap(pool: &PgPool, label: Option<String>) -> Result<()>
Mint a global administrative credential. The one operation that needs a database connection and no prior credential: everything else can be done remotely with the credential this prints.