pub struct AgentInfo {
pub name: String,
pub display_name: Option<String>,
pub status: String,
pub repo: Option<String>,
pub branch: Option<String>,
pub activity: Option<String>,
pub last_seen: Option<String>,
pub online: bool,
}Fields
name: Stringdisplay_name: Option<String>status: StringOne of active, idle, offline. offline means the presence lease
expired, i.e. the agent has not sent a heartbeat recently.
repo: Option<String>branch: Option<String>activity: Option<String>Free-text description of what this agent is currently doing.
last_seen: Option<String>online: boolTrait Implementations
Sourceimpl JsonSchema for AgentInfo
impl JsonSchema for AgentInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentInfo
impl RefUnwindSafe for AgentInfo
impl Send for AgentInfo
impl Sync for AgentInfo
impl Unpin for AgentInfo
impl UnsafeUnpin for AgentInfo
impl UnwindSafe for AgentInfo