pub struct AgentList {
pub agents: Vec<AgentInfo>,
pub online_count: usize,
}Fields
agents: Vec<AgentInfo>online_count: usizeTrait Implementations
Sourceimpl JsonSchema for AgentList
impl JsonSchema for AgentList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentList
impl RefUnwindSafe for AgentList
impl Send for AgentList
impl Sync for AgentList
impl Unpin for AgentList
impl UnsafeUnpin for AgentList
impl UnwindSafe for AgentList