pub struct AgentSession {
pub session: Option<String>,
pub status: String,
pub repo: Option<String>,
pub branch: Option<String>,
pub activity: Option<String>,
pub last_seen: Option<String>,
pub online: bool,
}Expand description
One working context of an agent: what that session is doing right now.
Fields
session: Option<String>Absent for the shared session.
status: Stringrepo: Option<String>branch: Option<String>activity: Option<String>last_seen: Option<String>online: boolTrait Implementations
Sourceimpl Debug for AgentSession
impl Debug for AgentSession
Sourceimpl JsonSchema for AgentSession
impl JsonSchema for AgentSession
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentSession
impl RefUnwindSafe for AgentSession
impl Send for AgentSession
impl Sync for AgentSession
impl Unpin for AgentSession
impl UnsafeUnpin for AgentSession
impl UnwindSafe for AgentSession