pub struct ChannelInfo {
pub name: String,
pub topic: Option<String>,
pub message_count: i64,
pub created_at: String,
}Fields
name: Stringtopic: Option<String>message_count: i64created_at: StringTrait Implementations
Sourceimpl Debug for ChannelInfo
impl Debug for ChannelInfo
Sourceimpl JsonSchema for ChannelInfo
impl JsonSchema for ChannelInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChannelInfo
impl RefUnwindSafe for ChannelInfo
impl Send for ChannelInfo
impl Sync for ChannelInfo
impl Unpin for ChannelInfo
impl UnsafeUnpin for ChannelInfo
impl UnwindSafe for ChannelInfo