pub struct ConversationActivity {
pub conversation_id: String,
pub title: String,
pub last_seq: i64,
pub unacknowledged: i64,
}Fields
conversation_id: Stringtitle: Stringlast_seq: i64Highest sequence currently stored in the thread. It is not a read cursor: it does not move with what you have read or acknowledged.
unacknowledged: i64Messages addressed to you that you have not acknowledged.