pub struct ConversationList {
pub conversations: Vec<ConversationInfo>,
}Fields
conversations: Vec<ConversationInfo>Trait Implementations
Sourceimpl Debug for ConversationList
impl Debug for ConversationList
Sourceimpl JsonSchema for ConversationList
impl JsonSchema for ConversationList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConversationList
impl RefUnwindSafe for ConversationList
impl Send for ConversationList
impl Sync for ConversationList
impl Unpin for ConversationList
impl UnsafeUnpin for ConversationList
impl UnwindSafe for ConversationList