pub struct ConversationUpdates {
pub conversations: Vec<ConversationActivity>,
pub waited_seconds: i64,
}Expand description
What wait_for_conversation_updates reports.
Fields
conversations: Vec<ConversationActivity>waited_seconds: i64Trait Implementations
Sourceimpl Debug for ConversationUpdates
impl Debug for ConversationUpdates
Sourceimpl JsonSchema for ConversationUpdates
impl JsonSchema for ConversationUpdates
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConversationUpdates
impl RefUnwindSafe for ConversationUpdates
impl Send for ConversationUpdates
impl Sync for ConversationUpdates
impl Unpin for ConversationUpdates
impl UnsafeUnpin for ConversationUpdates
impl UnwindSafe for ConversationUpdates