pub struct DigestAgent {
pub name: String,
pub activity: Option<String>,
pub last_seen: Option<String>,
pub online: bool,
}Fields
name: Stringactivity: Option<String>last_seen: Option<String>online: boolTrait Implementations
Sourceimpl Debug for DigestAgent
impl Debug for DigestAgent
Sourceimpl JsonSchema for DigestAgent
impl JsonSchema for DigestAgent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DigestAgent
impl RefUnwindSafe for DigestAgent
impl Send for DigestAgent
impl Sync for DigestAgent
impl Unpin for DigestAgent
impl UnsafeUnpin for DigestAgent
impl UnwindSafe for DigestAgent