pub struct DigestChannel {
pub name: String,
pub message_count: i64,
pub last_messages: Vec<DigestMessage>,
}Fields
name: Stringmessage_count: i64last_messages: Vec<DigestMessage>Trait Implementations
Sourceimpl Debug for DigestChannel
impl Debug for DigestChannel
Sourceimpl JsonSchema for DigestChannel
impl JsonSchema for DigestChannel
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DigestChannel
impl RefUnwindSafe for DigestChannel
impl Send for DigestChannel
impl Sync for DigestChannel
impl Unpin for DigestChannel
impl UnsafeUnpin for DigestChannel
impl UnwindSafe for DigestChannel