pub struct DigestMessage {
pub from: String,
pub body: String,
pub at: String,
}Fields
from: Stringbody: Stringat: StringTrait Implementations
Sourceimpl Debug for DigestMessage
impl Debug for DigestMessage
Sourceimpl JsonSchema for DigestMessage
impl JsonSchema for DigestMessage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DigestMessage
impl RefUnwindSafe for DigestMessage
impl Send for DigestMessage
impl Sync for DigestMessage
impl Unpin for DigestMessage
impl UnsafeUnpin for DigestMessage
impl UnwindSafe for DigestMessage