pub struct DigestNote {
pub scope: String,
pub key: String,
pub updated_by: Option<String>,
pub updated_at: String,
}Fields
scope: Stringkey: Stringupdated_by: Option<String>updated_at: StringTrait Implementations
Sourceimpl Debug for DigestNote
impl Debug for DigestNote
Sourceimpl JsonSchema for DigestNote
impl JsonSchema for DigestNote
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DigestNote
impl RefUnwindSafe for DigestNote
impl Send for DigestNote
impl Sync for DigestNote
impl Unpin for DigestNote
impl UnsafeUnpin for DigestNote
impl UnwindSafe for DigestNote