pub struct DigestResult {
pub hours: i64,
pub channels: Vec<DigestChannel>,
pub tasks_moved: Vec<DigestTask>,
pub open_tasks: i64,
pub claimed_tasks: i64,
pub notes_updated: Vec<DigestNote>,
pub agents_seen: Vec<DigestAgent>,
pub active_locks: Vec<LockInfo>,
}Fields
hours: i64Window covered, in hours.
channels: Vec<DigestChannel>tasks_moved: Vec<DigestTask>Tasks whose state changed inside the window, newest first.
open_tasks: i64claimed_tasks: i64notes_updated: Vec<DigestNote>agents_seen: Vec<DigestAgent>active_locks: Vec<LockInfo>Trait Implementations
Sourceimpl Debug for DigestResult
impl Debug for DigestResult
Sourceimpl JsonSchema for DigestResult
impl JsonSchema for DigestResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DigestResult
impl RefUnwindSafe for DigestResult
impl Send for DigestResult
impl Sync for DigestResult
impl Unpin for DigestResult
impl UnsafeUnpin for DigestResult
impl UnwindSafe for DigestResult