pub struct DigestTask {
pub key: String,
pub title: String,
pub status: String,
pub claimed_by: Option<String>,
pub result: Option<String>,
pub updated_at: String,
}Fields
key: Stringtitle: Stringstatus: Stringclaimed_by: Option<String>result: Option<String>updated_at: StringTrait Implementations
Sourceimpl Debug for DigestTask
impl Debug for DigestTask
Sourceimpl JsonSchema for DigestTask
impl JsonSchema for DigestTask
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DigestTask
impl RefUnwindSafe for DigestTask
impl Send for DigestTask
impl Sync for DigestTask
impl Unpin for DigestTask
impl UnsafeUnpin for DigestTask
impl UnwindSafe for DigestTask