pub struct NoteInfo {
pub scope: String,
pub key: String,
pub value: String,
pub tags: Vec<String>,
pub updated_by: Option<String>,
pub updated_at: String,
}Fields
scope: Stringkey: Stringvalue: Stringupdated_by: Option<String>updated_at: StringTrait Implementations
Sourceimpl JsonSchema for NoteInfo
impl JsonSchema for NoteInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NoteInfo
impl RefUnwindSafe for NoteInfo
impl Send for NoteInfo
impl Sync for NoteInfo
impl Unpin for NoteInfo
impl UnsafeUnpin for NoteInfo
impl UnwindSafe for NoteInfo