pub struct NoteRef {
pub scope: String,
pub key: String,
pub found: bool,
pub note: Option<NoteInfo>,
}Fields
scope: Stringkey: Stringfound: boolnote: Option<NoteInfo>Trait Implementations
Sourceimpl JsonSchema for NoteRef
impl JsonSchema for NoteRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NoteRef
impl RefUnwindSafe for NoteRef
impl Send for NoteRef
impl Sync for NoteRef
impl Unpin for NoteRef
impl UnsafeUnpin for NoteRef
impl UnwindSafe for NoteRef