pub struct ProjectInfo {
pub id: String,
pub name: String,
pub members: Vec<String>,
pub archived: bool,
pub created_at: String,
}Expand description
A project: the unit a conversation can be visible to. Access is an explicit grant, never inferred from a directory or a role label.
Fields
id: Stringname: Stringmembers: Vec<String>Agents with an explicit grant. Only visible to someone who has one.
archived: boolcreated_at: StringTrait Implementations
Sourceimpl Debug for ProjectInfo
impl Debug for ProjectInfo
Sourceimpl JsonSchema for ProjectInfo
impl JsonSchema for ProjectInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProjectInfo
impl RefUnwindSafe for ProjectInfo
impl Send for ProjectInfo
impl Sync for ProjectInfo
impl Unpin for ProjectInfo
impl UnsafeUnpin for ProjectInfo
impl UnwindSafe for ProjectInfo