pub struct ProjectList {
pub projects: Vec<ProjectInfo>,
}Fields
projects: Vec<ProjectInfo>Trait Implementations
Sourceimpl Debug for ProjectList
impl Debug for ProjectList
Sourceimpl JsonSchema for ProjectList
impl JsonSchema for ProjectList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProjectList
impl RefUnwindSafe for ProjectList
impl Send for ProjectList
impl Sync for ProjectList
impl Unpin for ProjectList
impl UnsafeUnpin for ProjectList
impl UnwindSafe for ProjectList