pub struct SessionIdentity {
pub session_id: String,
pub epoch: i64,
pub registered_at: String,
pub expires_at: String,
pub expires_in_seconds: i64,
}Expand description
What a session credential proves, reported by whoami.
Fields
session_id: Stringepoch: i64registered_at: Stringexpires_at: Stringexpires_in_seconds: i64Trait Implementations
Sourceimpl Debug for SessionIdentity
impl Debug for SessionIdentity
Sourceimpl JsonSchema for SessionIdentity
impl JsonSchema for SessionIdentity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionIdentity
impl RefUnwindSafe for SessionIdentity
impl Send for SessionIdentity
impl Sync for SessionIdentity
impl Unpin for SessionIdentity
impl UnsafeUnpin for SessionIdentity
impl UnwindSafe for SessionIdentity