pub struct SessionList {
pub sessions: Vec<SessionEntry>,
pub count: usize,
pub limit: i64,
}Fields
sessions: Vec<SessionEntry>count: usizeSessions returned. When it equals the limit there may be more: narrow
with project or role.
limit: i64Trait Implementations
Sourceimpl Debug for SessionList
impl Debug for SessionList
Sourceimpl JsonSchema for SessionList
impl JsonSchema for SessionList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionList
impl RefUnwindSafe for SessionList
impl Send for SessionList
impl Sync for SessionList
impl Unpin for SessionList
impl UnsafeUnpin for SessionList
impl UnwindSafe for SessionList