pub struct TaskDetail {
pub task: TaskInfo,
pub history: Vec<TaskEventInfo>,
}Fields
task: TaskInfohistory: Vec<TaskEventInfo>Trait Implementations
Sourceimpl Debug for TaskDetail
impl Debug for TaskDetail
Sourceimpl JsonSchema for TaskDetail
impl JsonSchema for TaskDetail
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskDetail
impl RefUnwindSafe for TaskDetail
impl Send for TaskDetail
impl Sync for TaskDetail
impl Unpin for TaskDetail
impl UnsafeUnpin for TaskDetail
impl UnwindSafe for TaskDetail