pub struct TaskEventInfo {
pub event: String,
pub agent: Option<String>,
pub detail: Option<String>,
pub created_at: String,
}Fields
event: Stringagent: Option<String>detail: Option<String>created_at: StringTrait Implementations
Sourceimpl Debug for TaskEventInfo
impl Debug for TaskEventInfo
Sourceimpl JsonSchema for TaskEventInfo
impl JsonSchema for TaskEventInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskEventInfo
impl RefUnwindSafe for TaskEventInfo
impl Send for TaskEventInfo
impl Sync for TaskEventInfo
impl Unpin for TaskEventInfo
impl UnsafeUnpin for TaskEventInfo
impl UnwindSafe for TaskEventInfo