pub struct TaskInfo {Show 16 fields
pub key: String,
pub title: String,
pub description: Option<String>,
pub status: String,
pub depends_on: Vec<String>,
pub blocked: bool,
pub claimed_by: Option<String>,
pub claimed_at: Option<String>,
pub lease_expires_at: Option<String>,
pub lease_expired: bool,
pub result: Option<String>,
pub metadata: Value,
pub attachments: Vec<AttachmentMeta>,
pub created_by: Option<String>,
pub created_at: String,
pub updated_at: String,
}Fields
key: Stringtitle: Stringdescription: Option<String>status: StringOne of open, claimed, done, cancelled.
depends_on: Vec<String>Keys of tasks this one depends on.
blocked: boolTrue while any dependency is not yet done/cancelled. Blocked tasks cannot be claimed.
claimed_by: Option<String>claimed_at: Option<String>lease_expires_at: Option<String>When the current claim expires. After this instant another agent may steal the task, so renew the lease if you are still working on it.
lease_expired: boolTrue when the claim has already lapsed.
result: Option<String>metadata: Valueattachments: Vec<AttachmentMeta>Files attached to this task; fetch content with get_attachment.
created_by: Option<String>created_at: Stringupdated_at: StringTrait Implementations
Sourceimpl JsonSchema for TaskInfo
impl JsonSchema for TaskInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskInfo
impl RefUnwindSafe for TaskInfo
impl Send for TaskInfo
impl Sync for TaskInfo
impl Unpin for TaskInfo
impl UnsafeUnpin for TaskInfo
impl UnwindSafe for TaskInfo