pub struct TaskList {
pub tasks: Vec<TaskInfo>,
pub open: i64,
pub claimed: i64,
}Fields
tasks: Vec<TaskInfo>open: i64claimed: i64Trait Implementations
Sourceimpl JsonSchema for TaskList
impl JsonSchema for TaskList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskList
impl RefUnwindSafe for TaskList
impl Send for TaskList
impl Sync for TaskList
impl Unpin for TaskList
impl UnsafeUnpin for TaskList
impl UnwindSafe for TaskList