pub struct TransferResult {
pub conversation_id: String,
pub from_address: String,
pub to_address: String,
pub state: String,
}Expand description
Result of a membership transfer proposal or acceptance.
Fields
conversation_id: Stringfrom_address: StringThe membership that will be superseded once the target accepts.
to_address: Stringstate: StringTrait Implementations
Sourceimpl Debug for TransferResult
impl Debug for TransferResult
Sourceimpl JsonSchema for TransferResult
impl JsonSchema for TransferResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TransferResult
impl RefUnwindSafe for TransferResult
impl Send for TransferResult
impl Sync for TransferResult
impl Unpin for TransferResult
impl UnsafeUnpin for TransferResult
impl UnwindSafe for TransferResult