pub struct SessionProof {
pub token: String,
pub session_id: String,
pub epoch: i64,
pub expires_at: String,
}Expand description
The credential this window proved itself with, when the bus issues them.
Fields
token: StringThe secret. Written only to the 0600 binding file, never to a tool result, a log or argv.
session_id: Stringepoch: i64expires_at: StringTrait Implementations
Sourceimpl Clone for SessionProof
impl Clone for SessionProof