pub async fn admin_bootstrap(pool: &PgPool, label: Option<String>) -> Result<()>Expand description
Mint a global administrative credential. The one operation that needs a database connection and no prior credential: everything else can be done remotely with the credential this prints.