pub struct MessageInfo {
pub id: i64,
pub from: String,
pub channel: Option<String>,
pub to: Option<String>,
pub body: String,
pub reply_to: Option<i64>,
pub metadata: Value,
pub attachments: Vec<AttachmentMeta>,
pub created_at: String,
}Fields
id: i64from: Stringchannel: Option<String>Channel name for channel messages; null for direct messages.
to: Option<String>Recipient handle for direct messages; null for channel messages.
body: Stringreply_to: Option<i64>metadata: Valueattachments: Vec<AttachmentMeta>Files attached to this message; fetch content with get_attachment.
created_at: StringTrait Implementations
Sourceimpl Debug for MessageInfo
impl Debug for MessageInfo
Sourceimpl JsonSchema for MessageInfo
impl JsonSchema for MessageInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MessageInfo
impl RefUnwindSafe for MessageInfo
impl Send for MessageInfo
impl Sync for MessageInfo
impl Unpin for MessageInfo
impl UnsafeUnpin for MessageInfo
impl UnwindSafe for MessageInfo